import argparse
from .core import is_sixty_nine


def main() -> None:
    parser = argparse.ArgumentParser(
        prog="is-sixty-nine",
        description="Check if a given value is 69.",
    )
    parser.add_argument("value", help="Value to check")
    args = parser.parse_args()

    if is_sixty_nine(args.value):
        print("YES: the value you entered is 69.")
    else:
        print("NO: the value you entered is not 69.")



from is_sixty_nine import is_sixty_nine


def test_exact_69():
    assert is_sixty_nine(69)
    assert is_sixty_nine("69")


def test_not_69():
    assert not is_sixty_nine(70)
    assert not is_sixty_nine("68")
    assert not is_sixty_nine(None)
    assert not is_sixty_nine("not a number")



def is_sixty_nine(value) -> bool:
    """
    Return True if the number is 69, False otherwise.
    """
    try:
        number = int(value)
    except (TypeError, ValueError):
        return False

    return number == 69
